@@ -16,7 +16,22 @@ class Data:
         
         Attributes:
             as_list (List[Any]): original data retrieved from Api resource
-            as_dataframe (pandas.Dataframe): data as pandas' DataFrame object, converted using `pandas._json_normalize()`
+            as_dataframe (pandas.Dataframe): data as pandas DataFrame object, converted using `pandas._json_normalize()`.
+                You can then use various methods, which `pandas.DataFrame` class provides, e.g. for saving data
+                in various file types.
+
+        Examples:
+
+            >>> from apitalker.api import API
+            >>> 
+            >>> api = API("yourapikey")
+            >>> 
+            >>> data, error = api.get_data("/path/to/resource/", **kwargs)
+            >>> 
+            >>> if error is None:
+            >>>     data.as_dataframe.to_json()
+            >>>     data.as_dataframe.to_csv()
+
         """
         self.as_list: List[Any] = data
         self.as_dataframe: DataFrame = self.to_dataframe()
